@@ -3,7 +3,7 @@ is.what <- function(object, verbose=FALSE)
   do.test <- function(test, object)
   {
     result <- try(get(test)(object), silent=TRUE)
-    if(!is.logical(result) || length(result)!=1)
+    if(!is.logical(result) || is.na(result) || length(result)!=1)
       result <- NULL
     return(result)
   }
@@ -14,20 +14,13 @@ is.what <- function(object, verbose=FALSE)
   ## Narrow to functions
   is.functions <- is.names[sapply(is.names, function(x) is.function(get(x)))]
 
-  tests <- sort(unique(is.functions))
+  tests <- sort(unique(is.functions[is.functions!="is.what"]))
   results <- suppressWarnings(unlist(sapply(tests, do.test, object=object)))
 
   if(verbose)
-  {
-    results <- as.character(results)
-    results[results=="TRUE"] <- "T"
-    results[results=="FALSE"] <- "."
-    output <- data.frame(is=results)
-  }
+    output <- data.frame(is=ifelse(results,"T","."))
   else
-  {
     output <- names(results)[results]
-  }
 
   return(output)
 }
